==> grafana-alloy-debug-1.12.2-1-x86_64.pkg.tar.zst: usr/src/debug/grafana-alloy/pkg/mod/github.com/!data!dog/datadog-api-client-go/v2@v2.48.0/api/datadogV2/model_convert_job_results_to_signals_data.go <==
// Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
// This product includes software developed at Datadog (https://www.datadoghq.com/).
// Copyright 2019-Present Datadog, Inc.

package datadogV2

import (
	"github.com/DataDog/datadog-api-client-go/v2/api/datadog"
)

// ConvertJobResultsToSignalsData Data for converting historical job results to signals.
type ConvertJobResultsToSignalsData struct {
	// Attributes for converting historical job results to signals.
	Attributes *ConvertJobResultsToSignalsAttributes `json:"attributes,omitempty"`
	// Type of payload.
	Type *ConvertJobResultsToSignalsDataType `json:"type,omitempty"`
	// UnparsedObject contains the raw value of the object if there was an error when deserializing into the struct
	UnparsedObject       map[string]interface{} `json:"-"`
	AdditionalProperties map[string]interface{} `json:"-"`
}

// NewConvertJobResultsToSignalsData instantiates a new ConvertJobResultsToSignalsData object.
// This constructor will assign default values to properties that have it defined,
// and makes sure properties required by API are set, but the set of arguments
// will change when the set of required properties is changed.
func NewConvertJobResultsToSignalsData() *ConvertJobResultsToSignalsData {
	this := ConvertJobResultsToSignalsData{}
	return &this
}

// NewConvertJobResultsToSignalsDataWithDefaults instantiates a new ConvertJobResultsToSignalsData object.
// This constructor will only assign default values to properties that have it defined,
// but it doesn't guarantee that properties required by API are set.
func NewConvertJobResultsToSignalsDataWithDefaults() *ConvertJobResultsToSignalsData {
	this := ConvertJobResultsToSignalsData{}
	return &this
}

// GetAttributes returns the Attributes field value if set, zero value otherwise.
func (o *ConvertJobResultsToSignalsData) GetAttributes() ConvertJobResultsToSignalsAttributes {
	if o == nil || o.Attributes == nil {
		var ret ConvertJobResultsToSignalsAttributes
		return ret
	}
	return *o.Attributes
}

// GetAttributesOk returns a tuple with the Attributes field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *ConvertJobResultsToSignalsData) GetAttributesOk() (*ConvertJobResultsToSignalsAttributes, bool) {
	if o == nil || o.Attributes == nil {
		return nil, false
	}
	return o.Attributes, true
}

// HasAttributes returns a boolean if a field has been set.
func (o *ConvertJobResultsToSignalsData) HasAttributes() bool {
	return o != nil && o.Attributes != nil
}

// SetAttributes gets a reference to the given ConvertJobResultsToSignalsAttributes and assigns it to the Attributes field.
func (o *ConvertJobResultsToSignalsData) SetAttributes(v ConvertJobResultsToSignalsAttributes) {
	o.Attributes = &v
}

// GetType returns the Type field value if set, zero value otherwise.
func (o *ConvertJobResultsToSignalsData) GetType() ConvertJobResultsToSignalsDataType {
	if o == nil || o.Type == nil {
		var ret ConvertJobResultsToSignalsDataType
		return ret
	}
	return *o.Type
}

// GetTypeOk returns a tuple with the Type field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *ConvertJobResultsToSignalsData) GetTypeOk() (*ConvertJobResultsToSignalsDataType, bool) {
	if o == nil || o.Type == nil {
		return nil, false
	}
	return o.Type, true
}

// HasType returns a boolean if a field has been set.
func (o *ConvertJobResultsToSignalsData) HasType() bool {
	return o != nil && o.Type != nil
}

// SetType gets a reference to the given ConvertJobResultsToSignalsDataType and assigns it to the Type field.
func (o *ConvertJobResultsToSignalsData) SetType(v ConvertJobResultsToSignalsDataType) {
	o.Type = &v
}

// MarshalJSON serializes the struct using spec logic.
func (o ConvertJobResultsToSignalsData) MarshalJSON() ([]byte, error) {
	toSerialize := map[string]interface{}{}
	if o.UnparsedObject != nil {
		return datadog.Marshal(o.UnparsedObject)
	}
	if o.Attributes != nil {
		toSerialize["attributes"] = o.Attributes
	}
	if o.Type != nil {
		toSerialize["type"] = o.Type
	}

	for key, value := range o.AdditionalProperties {
		toSerialize[key] = value
	}
	return datadog.Marshal(toSerialize)
}

// UnmarshalJSON deserializes the given payload.
func (o *ConvertJobResultsToSignalsData) UnmarshalJSON(bytes []byte) (err error) {
	all := struct {
		Attributes *ConvertJobResultsToSignalsAttributes `json:"attributes,omitempty"`
		Type       *ConvertJobResultsToSignalsDataType   `json:"type,omitempty"`
	}{}
	if err = datadog.Unmarshal(bytes, &all); err != nil {
		return datadog.Unmarshal(bytes, &o.UnparsedObject)
	}
	additionalProperties := make(map[string]interface{})
	if err = datadog.Unmarshal(bytes, &additionalProperties); err == nil {
		datadog.DeleteKeys(additionalProperties, &[]string{"attributes", "type"})
	} else {
		return err
	}

	hasInvalidField := false
	if all.Attributes != nil && all.Attributes.UnparsedObject != nil && o.UnparsedObject == nil {
		hasInvalidField = true
	}
	o.Attributes = all.Attributes
	if all.Type != nil && !all.Type.IsValid() {
		hasInvalidField = true
	} else {
		o.Type = all.Type
	}

	if len(additionalProperties) > 0 {
		o.AdditionalProperties = additionalProperties
	}

	if hasInvalidField {
		return datadog.Unmarshal(bytes, &o.UnparsedObject)
	}

	return nil
}

==> grafana-alloy-debug-1.13.0-1-x86_64.pkg.tar.zst: usr/src/debug/grafana-alloy/pkg/mod/github.com/!data!dog/datadog-api-client-go/v2@v2.51.0/api/datadogV2/model_convert_job_results_to_signals_data.go <==
// Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
// This product includes software developed at Datadog (https://www.datadoghq.com/).
// Copyright 2019-Present Datadog, Inc.

package datadogV2

import (
	"github.com/DataDog/datadog-api-client-go/v2/api/datadog"
)

// ConvertJobResultsToSignalsData Data for converting threat hunting job results to signals.
type ConvertJobResultsToSignalsData struct {
	// Attributes for converting threat hunting job results to signals.
	Attributes *ConvertJobResultsToSignalsAttributes `json:"attributes,omitempty"`
	// Type of payload.
	Type *ConvertJobResultsToSignalsDataType `json:"type,omitempty"`
	// UnparsedObject contains the raw value of the object if there was an error when deserializing into the struct
	UnparsedObject       map[string]interface{} `json:"-"`
	AdditionalProperties map[string]interface{} `json:"-"`
}

// NewConvertJobResultsToSignalsData instantiates a new ConvertJobResultsToSignalsData object.
// This constructor will assign default values to properties that have it defined,
// and makes sure properties required by API are set, but the set of arguments
// will change when the set of required properties is changed.
func NewConvertJobResultsToSignalsData() *ConvertJobResultsToSignalsData {
	this := ConvertJobResultsToSignalsData{}
	return &this
}

// NewConvertJobResultsToSignalsDataWithDefaults instantiates a new ConvertJobResultsToSignalsData object.
// This constructor will only assign default values to properties that have it defined,
// but it doesn't guarantee that properties required by API are set.
func NewConvertJobResultsToSignalsDataWithDefaults() *ConvertJobResultsToSignalsData {
	this := ConvertJobResultsToSignalsData{}
	return &this
}

// GetAttributes returns the Attributes field value if set, zero value otherwise.
func (o *ConvertJobResultsToSignalsData) GetAttributes() ConvertJobResultsToSignalsAttributes {
	if o == nil || o.Attributes == nil {
		var ret ConvertJobResultsToSignalsAttributes
		return ret
	}
	return *o.Attributes
}

// GetAttributesOk returns a tuple with the Attributes field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *ConvertJobResultsToSignalsData) GetAttributesOk() (*ConvertJobResultsToSignalsAttributes, bool) {
	if o == nil || o.Attributes == nil {
		return nil, false
	}
	return o.Attributes, true
}

// HasAttributes returns a boolean if a field has been set.
func (o *ConvertJobResultsToSignalsData) HasAttributes() bool {
	return o != nil && o.Attributes != nil
}

// SetAttributes gets a reference to the given ConvertJobResultsToSignalsAttributes and assigns it to the Attributes field.
func (o *ConvertJobResultsToSignalsData) SetAttributes(v ConvertJobResultsToSignalsAttributes) {
	o.Attributes = &v
}

// GetType returns the Type field value if set, zero value otherwise.
func (o *ConvertJobResultsToSignalsData) GetType() ConvertJobResultsToSignalsDataType {
	if o == nil || o.Type == nil {
		var ret ConvertJobResultsToSignalsDataType
		return ret
	}
	return *o.Type
}

// GetTypeOk returns a tuple with the Type field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *ConvertJobResultsToSignalsData) GetTypeOk() (*ConvertJobResultsToSignalsDataType, bool) {
	if o == nil || o.Type == nil {
		return nil, false
	}
	return o.Type, true
}

// HasType returns a boolean if a field has been set.
func (o *ConvertJobResultsToSignalsData) HasType() bool {
	return o != nil && o.Type != nil
}

// SetType gets a reference to the given ConvertJobResultsToSignalsDataType and assigns it to the Type field.
func (o *ConvertJobResultsToSignalsData) SetType(v ConvertJobResultsToSignalsDataType) {
	o.Type = &v
}

// MarshalJSON serializes the struct using spec logic.
func (o ConvertJobResultsToSignalsData) MarshalJSON() ([]byte, error) {
	toSerialize := map[string]interface{}{}
	if o.UnparsedObject != nil {
		return datadog.Marshal(o.UnparsedObject)
	}
	if o.Attributes != nil {
		toSerialize["attributes"] = o.Attributes
	}
	if o.Type != nil {
		toSerialize["type"] = o.Type
	}

	for key, value := range o.AdditionalProperties {
		toSerialize[key] = value
	}
	return datadog.Marshal(toSerialize)
}

// UnmarshalJSON deserializes the given payload.
func (o *ConvertJobResultsToSignalsData) UnmarshalJSON(bytes []byte) (err error) {
	all := struct {
		Attributes *ConvertJobResultsToSignalsAttributes `json:"attributes,omitempty"`
		Type       *ConvertJobResultsToSignalsDataType   `json:"type,omitempty"`
	}{}
	if err = datadog.Unmarshal(bytes, &all); err != nil {
		return datadog.Unmarshal(bytes, &o.UnparsedObject)
	}
	additionalProperties := make(map[string]interface{})
	if err = datadog.Unmarshal(bytes, &additionalProperties); err == nil {
		datadog.DeleteKeys(additionalProperties, &[]string{"attributes", "type"})
	} else {
		return err
	}

	hasInvalidField := false
	if all.Attributes != nil && all.Attributes.UnparsedObject != nil && o.UnparsedObject == nil {
		hasInvalidField = true
	}
	o.Attributes = all.Attributes
	if all.Type != nil && !all.Type.IsValid() {
		hasInvalidField = true
	} else {
		o.Type = all.Type
	}

	if len(additionalProperties) > 0 {
		o.AdditionalProperties = additionalProperties
	}

	if hasInvalidField {
		return datadog.Unmarshal(bytes, &o.UnparsedObject)
	}

	return nil
}
